/*******************************************************************************
* File Name: isrTargetINT.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <isrTargetINT.H>

#if !defined(isrTargetINT__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START isrTargetINT_intc` */
#include "SGPIO_Target.h"
#include "main.h"

extern uint16 SDIN, SDOUT, L30;
extern uint8 SGPIO_DataFlag;
/* `#END` */

extern cyisraddress CyRamVectors[CYINT_IRQ_BASE + CY_NUM_INTERRUPTS];

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: isrTargetINT_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void isrTargetINT_Start(void)
{
    /* For all we know the interrupt is active. */
    isrTargetINT_Disable();

    /* Set the ISR to point to the isrTargetINT Interrupt. */
    isrTargetINT_SetVector(&isrTargetINT_Interrupt);

    /* Set the priority. */
    isrTargetINT_SetPriority((uint8)isrTargetINT_INTC_PRIOR_NUMBER);

    /* Enable it. */
    isrTargetINT_Enable();
}


/*******************************************************************************
* Function Name: isrTargetINT_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void isrTargetINT_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    isrTargetINT_Disable();

    /* Set the ISR to point to the isrTargetINT Interrupt. */
    isrTargetINT_SetVector(address);

    /* Set the priority. */
    isrTargetINT_SetPriority((uint8)isrTargetINT_INTC_PRIOR_NUMBER);

    /* Enable it. */
    isrTargetINT_Enable();
}


/*******************************************************************************
* Function Name: isrTargetINT_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void isrTargetINT_Stop(void)
{
    /* Disable this interrupt. */
    isrTargetINT_Disable();

    /* Set the ISR to point to the passive one. */
    isrTargetINT_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: isrTargetINT_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for isrTargetINT.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(isrTargetINT_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START isrTargetINT_Interrupt` */
	// Read SDOUT data and vendor specific L3:0 data from the Rx FIFO //
	SDOUT = SGPIO_Target_ReadRxData();
	L30   = SGPIO_Target_ReadRxData();
	// Send back whatever was received for transmission out on SDIN next frame //
	SGPIO_Target_WriteTxData(SDOUT); 
	SGPIO_DataFlag = TRUE;
	SGPIO_Target_GetStatus();
	
	SGPIO_Target_ClearRxBuffer(); // Clear the receive buffer


    /* `#END` */
}


/*******************************************************************************
* Function Name: isrTargetINT_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling isrTargetINT_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use isrTargetINT_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void isrTargetINT_SetVector(cyisraddress address)
{
    CyRamVectors[CYINT_IRQ_BASE + isrTargetINT__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: isrTargetINT_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress isrTargetINT_GetVector(void)
{
    return CyRamVectors[CYINT_IRQ_BASE + isrTargetINT__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: isrTargetINT_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling isrTargetINT_Start
*   or isrTargetINT_StartEx will override any effect this method would 
*   have had. This method should only be called after isrTargetINT_Start or 
*   isrTargetINT_StartEx has been called. To set the initial
*   priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 3, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void isrTargetINT_SetPriority(uint8 priority)
{
	uint8 interruptState;
    uint32 priorityOffset = ((isrTargetINT__INTC_NUMBER % 4u) * 8u) + 6u;
    
	interruptState = CyEnterCriticalSection();
    *isrTargetINT_INTC_PRIOR = (*isrTargetINT_INTC_PRIOR & (uint32)(~isrTargetINT__INTC_PRIOR_MASK)) |
                                    ((uint32)priority << priorityOffset);
	CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: isrTargetINT_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 3, 0 being the highest.
*
*******************************************************************************/
uint8 isrTargetINT_GetPriority(void)
{
    uint32 priority;
	uint32 priorityOffset = ((isrTargetINT__INTC_NUMBER % 4u) * 8u) + 6u;

    priority = (*isrTargetINT_INTC_PRIOR & isrTargetINT__INTC_PRIOR_MASK) >> priorityOffset;

    return (uint8)priority;
}


/*******************************************************************************
* Function Name: isrTargetINT_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void isrTargetINT_Enable(void)
{
    /* Enable the general interrupt. */
    *isrTargetINT_INTC_SET_EN = isrTargetINT__INTC_MASK;
}


/*******************************************************************************
* Function Name: isrTargetINT_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 isrTargetINT_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*isrTargetINT_INTC_SET_EN & (uint32)isrTargetINT__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: isrTargetINT_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void isrTargetINT_Disable(void)
{
    /* Disable the general interrupt. */
    *isrTargetINT_INTC_CLR_EN = isrTargetINT__INTC_MASK;
}


/*******************************************************************************
* Function Name: isrTargetINT_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void isrTargetINT_SetPending(void)
{
    *isrTargetINT_INTC_SET_PD = isrTargetINT__INTC_MASK;
}


/*******************************************************************************
* Function Name: isrTargetINT_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void isrTargetINT_ClearPending(void)
{
    *isrTargetINT_INTC_CLR_PD = isrTargetINT__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
