/*******************************************************************************
* File Name: isrTimeout.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <isrTimeout.H>

#if !defined(isrTimeout__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START isrTimeout_intc` */

/* `#END` */

extern cyisraddress CyRamVectors[CYINT_IRQ_BASE + CY_NUM_INTERRUPTS];

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: isrTimeout_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void isrTimeout_Start(void)
{
    /* For all we know the interrupt is active. */
    isrTimeout_Disable();

    /* Set the ISR to point to the isrTimeout Interrupt. */
    isrTimeout_SetVector(&isrTimeout_Interrupt);

    /* Set the priority. */
    isrTimeout_SetPriority((uint8)isrTimeout_INTC_PRIOR_NUMBER);

    /* Enable it. */
    isrTimeout_Enable();
}


/*******************************************************************************
* Function Name: isrTimeout_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void isrTimeout_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    isrTimeout_Disable();

    /* Set the ISR to point to the isrTimeout Interrupt. */
    isrTimeout_SetVector(address);

    /* Set the priority. */
    isrTimeout_SetPriority((uint8)isrTimeout_INTC_PRIOR_NUMBER);

    /* Enable it. */
    isrTimeout_Enable();
}


/*******************************************************************************
* Function Name: isrTimeout_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void isrTimeout_Stop(void)
{
    /* Disable this interrupt. */
    isrTimeout_Disable();

    /* Set the ISR to point to the passive one. */
    isrTimeout_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: isrTimeout_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for isrTimeout.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(isrTimeout_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START isrTimeout_Interrupt` */

    /* `#END` */
}


/*******************************************************************************
* Function Name: isrTimeout_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling isrTimeout_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use isrTimeout_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void isrTimeout_SetVector(cyisraddress address)
{
    CyRamVectors[CYINT_IRQ_BASE + isrTimeout__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: isrTimeout_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress isrTimeout_GetVector(void)
{
    return CyRamVectors[CYINT_IRQ_BASE + isrTimeout__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: isrTimeout_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling isrTimeout_Start
*   or isrTimeout_StartEx will override any effect this method would 
*   have had. This method should only be called after isrTimeout_Start or 
*   isrTimeout_StartEx has been called. To set the initial
*   priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 3, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void isrTimeout_SetPriority(uint8 priority)
{
	uint8 interruptState;
    uint32 priorityOffset = ((isrTimeout__INTC_NUMBER % 4u) * 8u) + 6u;
    
	interruptState = CyEnterCriticalSection();
    *isrTimeout_INTC_PRIOR = (*isrTimeout_INTC_PRIOR & (uint32)(~isrTimeout__INTC_PRIOR_MASK)) |
                                    ((uint32)priority << priorityOffset);
	CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: isrTimeout_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 3, 0 being the highest.
*
*******************************************************************************/
uint8 isrTimeout_GetPriority(void)
{
    uint32 priority;
	uint32 priorityOffset = ((isrTimeout__INTC_NUMBER % 4u) * 8u) + 6u;

    priority = (*isrTimeout_INTC_PRIOR & isrTimeout__INTC_PRIOR_MASK) >> priorityOffset;

    return (uint8)priority;
}


/*******************************************************************************
* Function Name: isrTimeout_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void isrTimeout_Enable(void)
{
    /* Enable the general interrupt. */
    *isrTimeout_INTC_SET_EN = isrTimeout__INTC_MASK;
}


/*******************************************************************************
* Function Name: isrTimeout_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 isrTimeout_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*isrTimeout_INTC_SET_EN & (uint32)isrTimeout__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: isrTimeout_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void isrTimeout_Disable(void)
{
    /* Disable the general interrupt. */
    *isrTimeout_INTC_CLR_EN = isrTimeout__INTC_MASK;
}


/*******************************************************************************
* Function Name: isrTimeout_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void isrTimeout_SetPending(void)
{
    *isrTimeout_INTC_SET_PD = isrTimeout__INTC_MASK;
}


/*******************************************************************************
* Function Name: isrTimeout_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void isrTimeout_ClearPending(void)
{
    *isrTimeout_INTC_CLR_PD = isrTimeout__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
