/*******************************************************************************
* File Name: `$INSTANCE_NAME`_PM.c
* Version `$CY_MAJOR_VERSION`.`$CY_MINOR_VERSION`
*
* Description:
*  This file contains the power management APIs for the SGPIO Target
*  component.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/
#include "`$INSTANCE_NAME`.h"

/* Backup structure just stores component's enable state prior to sleep */
static `$INSTANCE_NAME`_BACKUP_STRUCT `$INSTANCE_NAME`_backup = {0u, 0u};

/*******************************************************************************
* Function Name: `$INSTANCE_NAME`_SaveConfig
********************************************************************************
* Summary:
*  This API is used to save the configuration of the SGPIO_Target component prior
*  to PSoC entering low-power sleep mode. No register/parameters are required
*  to be saved.
* 
* Parameters:
*  None
* 
* Return:
*  None
* 
* Side Effects:
*  None
********************************************************************************/
void `$INSTANCE_NAME`_SaveConfig(void)
{
    /* Save component's interrupt enable state */
    if ((`$INSTANCE_NAME`_CONTROL_REG & `$INSTANCE_NAME`_INT_EN) == `$INSTANCE_NAME`_INT_EN)
    {
        `$INSTANCE_NAME`_backup.interruptEnableState = 1u;
    }
    /* Interrupts are disabled */
    else
    {
        `$INSTANCE_NAME`_backup.interruptEnableState = 0u;
    }
}

/*******************************************************************************
* Function Name: `$INSTANCE_NAME`_RestoreConfig
********************************************************************************
* Summary:
*  This API is used to restore the configuration of the SGPIO_Target component
*  after PSoC exits low-power sleep mode. No register/parameters are required
*  to be restored.
*
* Parameters:
*  None
* 
* Return:
*  None
* 
* Side Effects:
*  None
********************************************************************************/
void `$INSTANCE_NAME`_RestoreConfig(void) `=ReentrantKeil($INSTANCE_NAME . "_RestoreConfig")`
{
    /* Restore component's interrupt enable state */
    if (`$INSTANCE_NAME`_backup.interruptEnableState == 1u)
    {
        `$INSTANCE_NAME`_CONTROL_REG |= `$INSTANCE_NAME`_INT_EN;
    }
 }

/*******************************************************************************
* Function Name: `$INSTANCE_NAME`_Sleep
********************************************************************************
* Summary:
*  This API is used to configure the SGPIO_Target component for minimum power 
*  consumption prior to PSoC entering low-power sleep mode. Save the enable
*  state of the component, stop it and backup non-retention data to SRAM.
* 
* Parameters:
*  None
* 
* Return:
*  None
* 
* Side Effects:
*  None
********************************************************************************/
void `$INSTANCE_NAME`_Sleep(void)
{
    /* Save component's enable state */
    if ((`$INSTANCE_NAME`_CONTROL_REG & `$INSTANCE_NAME`_EN) == `$INSTANCE_NAME`_EN)
    {
        `$INSTANCE_NAME`_backup.enableState = 1u;
    }
    /* Component is disabled */
    else
    {
        `$INSTANCE_NAME`_backup.enableState = 0u;
    }
    `$INSTANCE_NAME`_SaveConfig();
    `$INSTANCE_NAME`_Stop();
}

/*******************************************************************************
* Function Name: `$INSTANCE_NAME`_WakeUp
********************************************************************************
* Summary:
*  This API is used to configure the SGPIO_Target component for active power 
*  consumption after PSoC exits low-power sleep mode. Restore non-retention data
*  from SRAM. Re-initialize the component and re-enable it if it was enabled
*  before going to sleep
*
* Parameters:
*  None
* 
* Return:
*  None
* 
* Side Effects:
*  None
********************************************************************************/
void `$INSTANCE_NAME`_WakeUp(void) `=ReentrantKeil($INSTANCE_NAME . "_Wakeup")`
{
    `$INSTANCE_NAME`_RestoreConfig();

    /* Re-initialize the component */
    `$INSTANCE_NAME`_Init();
    
    /* Restore component's enable state prior to going to sleep */
    /* Do nothing if component was disabled */
    if (`$INSTANCE_NAME`_backup.enableState != 0u)
    {
         /* Components block was enabled */
         `$INSTANCE_NAME`_Enable();
    }
}

/* [] END OF FILE */
