/*******************************************************************************
* File Name: SCLOCK.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "SCLOCK.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        SCLOCK_PC =   (SCLOCK_PC & \
                                (uint32)(~(uint32)(SCLOCK_DRIVE_MODE_IND_MASK << (SCLOCK_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (SCLOCK_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: SCLOCK_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void SCLOCK_Write(uint8 value) 
{
    uint8 drVal = (uint8)(SCLOCK_DR & (uint8)(~SCLOCK_MASK));
    drVal = (drVal | ((uint8)(value << SCLOCK_SHIFT) & SCLOCK_MASK));
    SCLOCK_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: SCLOCK_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void SCLOCK_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(SCLOCK__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: SCLOCK_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro SCLOCK_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 SCLOCK_Read(void) 
{
    return (uint8)((SCLOCK_PS & SCLOCK_MASK) >> SCLOCK_SHIFT);
}


/*******************************************************************************
* Function Name: SCLOCK_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 SCLOCK_ReadDataReg(void) 
{
    return (uint8)((SCLOCK_DR & SCLOCK_MASK) >> SCLOCK_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(SCLOCK_INTSTAT) 

    /*******************************************************************************
    * Function Name: SCLOCK_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 SCLOCK_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(SCLOCK_INTSTAT & SCLOCK_MASK);
		SCLOCK_INTSTAT = maskedStatus;
        return maskedStatus >> SCLOCK_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
