/*******************************************************************************
* File Name: SDOUT.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "SDOUT.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        SDOUT_PC =   (SDOUT_PC & \
                                (uint32)(~(uint32)(SDOUT_DRIVE_MODE_IND_MASK << (SDOUT_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (SDOUT_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: SDOUT_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void SDOUT_Write(uint8 value) 
{
    uint8 drVal = (uint8)(SDOUT_DR & (uint8)(~SDOUT_MASK));
    drVal = (drVal | ((uint8)(value << SDOUT_SHIFT) & SDOUT_MASK));
    SDOUT_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: SDOUT_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void SDOUT_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(SDOUT__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: SDOUT_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro SDOUT_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 SDOUT_Read(void) 
{
    return (uint8)((SDOUT_PS & SDOUT_MASK) >> SDOUT_SHIFT);
}


/*******************************************************************************
* Function Name: SDOUT_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 SDOUT_ReadDataReg(void) 
{
    return (uint8)((SDOUT_DR & SDOUT_MASK) >> SDOUT_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(SDOUT_INTSTAT) 

    /*******************************************************************************
    * Function Name: SDOUT_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 SDOUT_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(SDOUT_INTSTAT & SDOUT_MASK);
		SDOUT_INTSTAT = maskedStatus;
        return maskedStatus >> SDOUT_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
