/*******************************************************************************
* File Name: SGPIO_Target.h
* Version 1.40
*
* Description:
*  API function prototypes, customizer parameters and other constants for the
*  SGPIO Target component.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/
#include "cytypes.h"
#include "cyfitter.h"
#include "cylib.h"

#if !defined(SGPIO_Target_H)
#define SGPIO_Target_H

/*************************************** 
* API Function Prototypes 
***************************************/
void    SGPIO_Target_Start(void);
void    SGPIO_Target_Stop(void);
void    SGPIO_Target_Init(void) ;
void    SGPIO_Target_Enable(void) ;
void    SGPIO_Target_EnableInt(void) ;
void    SGPIO_Target_DisableInt(void) ;
uint8   SGPIO_Target_GetIntStatus(void) ;
uint8   SGPIO_Target_GetStatus(void);
void    SGPIO_Target_WriteTxData(uint16 txData) ;
uint16  SGPIO_Target_ReadRxData(void) ;
void    SGPIO_Target_ClearTxBuffer(void) ;
void    SGPIO_Target_ClearRxBuffer(void) ;
void    SGPIO_Target_ResetTimeout(void) ;
uint8   SGPIO_Target_GetTimeoutStatus(void) ;
void    SGPIO_Target_SaveConfig(void);
void    SGPIO_Target_RestoreConfig(void) ;
void    SGPIO_Target_Sleep(void);
void    SGPIO_Target_Wakeup(void) ;

/****************************************** 
* Parameters from the Component Customizer
******************************************/
#define SGPIO_Target_VendorSpecific 1

/****************************************** 
* Constants used by the firmware APIs
******************************************/
/* Bit field definitions for the Control Register */
#define SGPIO_Target_EN                 (0x01u)
#define SGPIO_Target_BUS_ACT_RST        (0x02u)
#define SGPIO_Target_INT_EN             (0x04u)

/* Bit field definitions for the Status Register */
#define SGPIO_Target_FULL_SYNC          (0x01u)
#define SGPIO_Target_BUS_ACT_BIT        (0x02u)
#define SGPIO_Target_RX_BUFF_AVAIL      (0x04u)
#define SGPIO_Target_TX_BUFF_AVAIL      (0x08u)

/* SGPIO sload sync pattern ('1' followed by 5 '0's) */
#define SGPIO_Target_SLOAD_SYNC         (0x80u)

/* Bit field definitions for the UDB registers */
#define SGPIO_Target_COUNT7_EN          (0x20u)
#define SGPIO_Target_F0_CLR             (0x0101u)
#define SGPIO_Target_F0_LVL             (0x0404u)
#define SGPIO_Target_F1_CLR             (0x0202u)
#define SGPIO_Target_F1_LVL             (0x0808u)

// Hardware Block Registers
#define SGPIO_Target_CONTROL_REG        (*(reg8 *)  SGPIO_Target_SyncCtlTCR_TargetControlReg__CONTROL_REG)
#define SGPIO_Target_CONTROL_PTR        ( (reg8 *)  SGPIO_Target_SyncCtlTCR_TargetControlReg__CONTROL_REG)
#define SGPIO_Target_STATUS_REG         (*(reg8 *)  SGPIO_Target_TargetStatusReg__STATUS_REG)
#define SGPIO_Target_STATUS_PTR         ( (reg8 *)  SGPIO_Target_TargetStatusReg__STATUS_REG)
#define SGPIO_Target_CNT7_AUX_CTL_REG   (*(reg8 *)  SGPIO_Target_TargetBitCounter__CONTROL_AUX_CTL_REG)
#define SGPIO_Target_CNT7_AUX_CTL_PTR   ( (reg8 *)  SGPIO_Target_TargetBitCounter__CONTROL_AUX_CTL_REG)

#if(CY_PSOC3)
    #define SGPIO_Target_DP_AUX_CTL_REG     (*(reg16 *) SGPIO_Target_TargetShiftReg_u0__DP_AUX_CTL_REG)
    #define SGPIO_Target_DP_AUX_CTL_PTR     ( (reg16 *) SGPIO_Target_TargetShiftReg_u0__DP_AUX_CTL_REG)
    #define SGPIO_Target_FIFO_F1_REG        (*(reg16 *) SGPIO_Target_TargetShiftReg_u0__F1_REG)
    #define SGPIO_Target_FIFO_F1_PTR        ( (reg16 *) SGPIO_Target_TargetShiftReg_u0__F1_REG)
    #define SGPIO_Target_FIFO_F0_REG        (*(reg16 *) SGPIO_Target_TargetShiftReg_u0__F0_REG)
    #define SGPIO_Target_FIFO_F0_PTR        ( (reg16 *) SGPIO_Target_TargetShiftReg_u0__F0_REG)
#else
    #define SGPIO_Target_DP_AUX_CTL_REG     (*(reg16 *) SGPIO_Target_TargetShiftReg_u0__16BIT_DP_AUX_CTL_REG)
    #define SGPIO_Target_DP_AUX_CTL_PTR     ( (reg16 *) SGPIO_Target_TargetShiftReg_u0__16BIT_DP_AUX_CTL_REG)
    #define SGPIO_Target_FIFO_F1_REG        (*(reg16 *) SGPIO_Target_TargetShiftReg_u0__16BIT_F1_REG)
    #define SGPIO_Target_FIFO_F1_PTR        ( (reg16 *) SGPIO_Target_TargetShiftReg_u0__16BIT_F1_REG)
    #define SGPIO_Target_FIFO_F0_REG        (*(reg16 *) SGPIO_Target_TargetShiftReg_u0__16BIT_F0_REG)
    #define SGPIO_Target_FIFO_F0_PTR        ( (reg16 *) SGPIO_Target_TargetShiftReg_u0__16BIT_F0_REG)
#endif

#define SGPIO_Target_DP_D1_REG          (*(reg8 *)  SGPIO_Target_TargetShiftReg_u1__D1_REG)
#define SGPIO_Target_DP_D1_PTR          ( (reg8 *)  SGPIO_Target_TargetShiftReg_u1__D1_REG)
/****************************************** 
* Power Management Support
******************************************/
/* Sleep mode support - backup component state before going to sleep */
typedef struct SGPIO_Target_backupStruct
{
    uint8 enableState;
    uint8 interruptEnableState;
} SGPIO_Target_BACKUP_STRUCT;

#endif // header sentry

//[] END OF FILE
