/*******************************************************************************
* File Name: SLOAD.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "SLOAD.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        SLOAD_PC =   (SLOAD_PC & \
                                (uint32)(~(uint32)(SLOAD_DRIVE_MODE_IND_MASK << (SLOAD_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (SLOAD_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: SLOAD_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void SLOAD_Write(uint8 value) 
{
    uint8 drVal = (uint8)(SLOAD_DR & (uint8)(~SLOAD_MASK));
    drVal = (drVal | ((uint8)(value << SLOAD_SHIFT) & SLOAD_MASK));
    SLOAD_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: SLOAD_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void SLOAD_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(SLOAD__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: SLOAD_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro SLOAD_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 SLOAD_Read(void) 
{
    return (uint8)((SLOAD_PS & SLOAD_MASK) >> SLOAD_SHIFT);
}


/*******************************************************************************
* Function Name: SLOAD_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 SLOAD_ReadDataReg(void) 
{
    return (uint8)((SLOAD_DR & SLOAD_MASK) >> SLOAD_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(SLOAD_INTSTAT) 

    /*******************************************************************************
    * Function Name: SLOAD_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 SLOAD_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(SLOAD_INTSTAT & SLOAD_MASK);
		SLOAD_INTSTAT = maskedStatus;
        return maskedStatus >> SLOAD_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
