/*******************************************************************************
* File Name: Timeout_Timer.c
* Version 1.0
*
* Description:
*  This file provides the source code to the API for the Timeout_Timer
*  component
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "Timeout_Timer.h"
#include "cyLib.h"

uint8 Timeout_Timer_initVar = 0u;


/*******************************************************************************
* Function Name: Timeout_Timer_Init
********************************************************************************
*
* Summary:
*  Initialize/Restore default Timeout_Timer configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_Init(void)
{

    /* Set values from customizer to CTRL */
    #if (Timeout_Timer__QUAD == Timeout_Timer_CONFIG)
        Timeout_Timer_CONTROL_REG =
        (((uint32)(Timeout_Timer_QUAD_ENCODING_MODES     << Timeout_Timer_QUAD_MODE_SHIFT))       |
         ((uint32)(Timeout_Timer_CONFIG                  << Timeout_Timer_MODE_SHIFT)));
    #endif  /* (Timeout_Timer__QUAD == Timeout_Timer_CONFIG) */

    #if (Timeout_Timer__PWM_SEL == Timeout_Timer_CONFIG)
        Timeout_Timer_CONTROL_REG =
        (((uint32)(Timeout_Timer_PWM_STOP_EVENT          << Timeout_Timer_PWM_STOP_KILL_SHIFT))    |
         ((uint32)(Timeout_Timer_PWM_OUT_INVERT          << Timeout_Timer_INV_OUT_SHIFT))         |
         ((uint32)(Timeout_Timer_PWM_OUT_N_INVERT        << Timeout_Timer_INV_COMPL_OUT_SHIFT))     |
         ((uint32)(Timeout_Timer_PWM_MODE                << Timeout_Timer_MODE_SHIFT)));

        #if (Timeout_Timer__PWM_PR == Timeout_Timer_PWM_MODE)
            Timeout_Timer_CONTROL_REG |=
            ((uint32)(Timeout_Timer_PWM_RUN_MODE         << Timeout_Timer_ONESHOT_SHIFT));

            Timeout_Timer_WriteCounter(Timeout_Timer_PWM_PR_INIT_VALUE);
        #else
            Timeout_Timer_CONTROL_REG |=
            (((uint32)(Timeout_Timer_PWM_ALIGN           << Timeout_Timer_UPDOWN_SHIFT))          |
             ((uint32)(Timeout_Timer_PWM_KILL_EVENT      << Timeout_Timer_PWM_SYNC_KILL_SHIFT)));
        #endif  /* (Timeout_Timer__PWM_PR == Timeout_Timer_PWM_MODE) */

        #if (Timeout_Timer__PWM_DT == Timeout_Timer_PWM_MODE)
            Timeout_Timer_CONTROL_REG |=
            ((uint32)(Timeout_Timer_PWM_DEAD_TIME_CYCLE  << Timeout_Timer_PRESCALER_SHIFT));
        #endif  /* (Timeout_Timer__PWM_DT == Timeout_Timer_PWM_MODE) */

        #if (Timeout_Timer__PWM == Timeout_Timer_PWM_MODE)
            Timeout_Timer_CONTROL_REG |=
            ((uint32)Timeout_Timer_PWM_PRESCALER         << Timeout_Timer_PRESCALER_SHIFT);
        #endif  /* (Timeout_Timer__PWM == Timeout_Timer_PWM_MODE) */
    #endif  /* (Timeout_Timer__PWM_SEL == Timeout_Timer_CONFIG) */

    #if (Timeout_Timer__TIMER == Timeout_Timer_CONFIG)
        Timeout_Timer_CONTROL_REG =
        (((uint32)(Timeout_Timer_TC_PRESCALER            << Timeout_Timer_PRESCALER_SHIFT))   |
         ((uint32)(Timeout_Timer_TC_COUNTER_MODE         << Timeout_Timer_UPDOWN_SHIFT))      |
         ((uint32)(Timeout_Timer_TC_RUN_MODE             << Timeout_Timer_ONESHOT_SHIFT))     |
         ((uint32)(Timeout_Timer_TC_COMP_CAP_MODE        << Timeout_Timer_MODE_SHIFT)));
    #endif  /* (Timeout_Timer__TIMER == Timeout_Timer_CONFIG) */

    /* Set values from customizer to CTRL1 */
    #if (Timeout_Timer__QUAD == Timeout_Timer_CONFIG)
        Timeout_Timer_TRIG_CONTROL1_REG  =
        (((uint32)(Timeout_Timer_QUAD_PHIA_SIGNAL_MODE   << Timeout_Timer_COUNT_SHIFT))       |
         ((uint32)(Timeout_Timer_QUAD_INDEX_SIGNAL_MODE  << Timeout_Timer_RELOAD_SHIFT))      |
         ((uint32)(Timeout_Timer_QUAD_STOP_SIGNAL_MODE   << Timeout_Timer_STOP_SHIFT))        |
         ((uint32)(Timeout_Timer_QUAD_PHIB_SIGNAL_MODE   << Timeout_Timer_START_SHIFT)));
    #endif  /* (Timeout_Timer__QUAD == Timeout_Timer_CONFIG) */

    #if (Timeout_Timer__PWM_SEL == Timeout_Timer_CONFIG)
        Timeout_Timer_TRIG_CONTROL1_REG  =
        (((uint32)(Timeout_Timer_PWM_SWITCH_SIGNAL_MODE  << Timeout_Timer_CAPTURE_SHIFT))     |
         ((uint32)(Timeout_Timer_PWM_COUNT_SIGNAL_MODE   << Timeout_Timer_COUNT_SHIFT))       |
         ((uint32)(Timeout_Timer_PWM_RELOAD_SIGNAL_MODE  << Timeout_Timer_RELOAD_SHIFT))      |
         ((uint32)(Timeout_Timer_PWM_STOP_SIGNAL_MODE    << Timeout_Timer_STOP_SHIFT))        |
         ((uint32)(Timeout_Timer_PWM_START_SIGNAL_MODE   << Timeout_Timer_START_SHIFT)));
    #endif  /* (Timeout_Timer__PWM_SEL == Timeout_Timer_CONFIG) */

    #if (Timeout_Timer__TIMER == Timeout_Timer_CONFIG)
        Timeout_Timer_TRIG_CONTROL1_REG  =
        (((uint32)(Timeout_Timer_TC_CAPTURE_SIGNAL_MODE  << Timeout_Timer_CAPTURE_SHIFT))     |
         ((uint32)(Timeout_Timer_TC_COUNT_SIGNAL_MODE    << Timeout_Timer_COUNT_SHIFT))       |
         ((uint32)(Timeout_Timer_TC_RELOAD_SIGNAL_MODE   << Timeout_Timer_RELOAD_SHIFT))      |
         ((uint32)(Timeout_Timer_TC_STOP_SIGNAL_MODE     << Timeout_Timer_STOP_SHIFT))        |
         ((uint32)(Timeout_Timer_TC_START_SIGNAL_MODE    << Timeout_Timer_START_SHIFT)));
    #endif  /* (Timeout_Timer__TIMER == Timeout_Timer_CONFIG) */

    /* Set values from customizer to INTR */
    #if (Timeout_Timer__QUAD == Timeout_Timer_CONFIG)
        Timeout_Timer_SetInterruptMode(Timeout_Timer_QUAD_INTERRUPT_MASK);
    #endif  /* (Timeout_Timer__QUAD == Timeout_Timer_CONFIG) */

    #if (Timeout_Timer__PWM_SEL == Timeout_Timer_CONFIG)
        Timeout_Timer_SetInterruptMode(Timeout_Timer_PWM_INTERRUPT_MASK);
    #endif  /* (Timeout_Timer__PWM_SEL == Timeout_Timer_CONFIG) */

    #if (Timeout_Timer__TIMER == Timeout_Timer_CONFIG)
        Timeout_Timer_SetInterruptMode(Timeout_Timer_TC_INTERRUPT_MASK);
    #endif  /* (Timeout_Timer__TIMER == Timeout_Timer_CONFIG) */

    /* Set other values from customizer */
    #if (Timeout_Timer__TIMER == Timeout_Timer_CONFIG)
        Timeout_Timer_WritePeriod(Timeout_Timer_TC_PERIOD_VALUE );
        #if (Timeout_Timer__COMPARE == Timeout_Timer_TC_COMP_CAP_MODE)
            Timeout_Timer_WriteCompare(Timeout_Timer_TC_COMPARE_VALUE);

            #if (1u == Timeout_Timer_TC_COMPARE_SWAP)
                Timeout_Timer_SetCompareSwap(1u);
                Timeout_Timer_WriteCompareBuf(Timeout_Timer_TC_COMPARE_BUF_VALUE);
            #endif  /* (1u == Timeout_Timer_TC_COMPARE_SWAP) */
        #endif  /* (Timeout_Timer__COMPARE == Timeout_Timer_TC_COMP_CAP_MODE) */
    #endif  /* (Timeout_Timer__TIMER == Timeout_Timer_CONFIG) */

    #if (Timeout_Timer__PWM_SEL == Timeout_Timer_CONFIG)
        Timeout_Timer_WritePeriod(Timeout_Timer_PWM_PERIOD_VALUE );
        Timeout_Timer_WriteCompare(Timeout_Timer_PWM_COMPARE_VALUE);

        #if (1u == Timeout_Timer_PWM_COMPARE_SWAP)
            Timeout_Timer_SetCompareSwap(1u);
            Timeout_Timer_WriteCompareBuf(Timeout_Timer_PWM_COMPARE_BUF_VALUE);
        #endif  /* (1u == Timeout_Timer_PWM_COMPARE_SWAP) */

        #if (1u == Timeout_Timer_PWM_PERIOD_SWAP)
            Timeout_Timer_SetPeriodSwap(1u);
            Timeout_Timer_WritePeriodBuf(Timeout_Timer_PWM_PERIOD_BUF_VALUE);
        #endif  /* (1u == Timeout_Timer_PWM_PERIOD_SWAP) */

        /* Set values from customizer to CTRL2 */
        #if (Timeout_Timer__PWM_PR == Timeout_Timer_PWM_MODE)
            Timeout_Timer_TRIG_CONTROL2_REG =
                    (Timeout_Timer_CC_MATCH_NO_CHANGE    |
                    Timeout_Timer_OVERLOW_NO_CHANGE      |
                    Timeout_Timer_UNDERFLOW_NO_CHANGE);
        #else
            #if (Timeout_Timer__LEFT == Timeout_Timer_PWM_ALIGN)
                Timeout_Timer_TRIG_CONTROL2_REG = Timeout_Timer_PWM_MODE_LEFT;
            #endif  /* ( Timeout_Timer_PWM_LEFT == Timeout_Timer_PWM_ALIGN) */

            #if (Timeout_Timer__RIGHT == Timeout_Timer_PWM_ALIGN)
                Timeout_Timer_TRIG_CONTROL2_REG = Timeout_Timer_PWM_MODE_RIGHT;
            #endif  /* ( Timeout_Timer_PWM_RIGHT == Timeout_Timer_PWM_ALIGN) */

            #if (Timeout_Timer__CENTER == Timeout_Timer_PWM_ALIGN)
                Timeout_Timer_TRIG_CONTROL2_REG = Timeout_Timer_PWM_MODE_CENTER;
            #endif  /* ( Timeout_Timer_PWM_CENTER == Timeout_Timer_PWM_ALIGN) */

            #if (Timeout_Timer__ASYMMETRIC == Timeout_Timer_PWM_ALIGN)
                Timeout_Timer_TRIG_CONTROL2_REG = Timeout_Timer_PWM_MODE_ASYM;
            #endif  /* (Timeout_Timer__ASYMMETRIC == Timeout_Timer_PWM_ALIGN) */
        #endif  /* (Timeout_Timer__PWM_PR == Timeout_Timer_PWM_MODE) */
    #endif  /* (Timeout_Timer__PWM_SEL == Timeout_Timer_CONFIG) */
}


/*******************************************************************************
* Function Name: Timeout_Timer_Enable
********************************************************************************
*
* Summary:
*  Enables the Timeout_Timer.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_Enable(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    Timeout_Timer_BLOCK_CONTROL_REG |= Timeout_Timer_MASK;
    CyExitCriticalSection(enableInterrupts);

    /* Statr Timer or PWM if start input is absent */
    #if (Timeout_Timer__PWM_SEL == Timeout_Timer_CONFIG)
        #if (0u == Timeout_Timer_PWM_START_SIGNAL_PRESENT)
            Timeout_Timer_TriggerCommand(Timeout_Timer_MASK, Timeout_Timer_CMD_START);
        #endif /* (0u == Timeout_Timer_PWM_START_SIGNAL_PRESENT) */
    #endif /* (Timeout_Timer__PWM_SEL == Timeout_Timer_CONFIG) */

    #if (Timeout_Timer__TIMER == Timeout_Timer_CONFIG)
        #if (0u == Timeout_Timer_TC_START_SIGNAL_PRESENT)
            Timeout_Timer_TriggerCommand(Timeout_Timer_MASK, Timeout_Timer_CMD_START);
        #endif /* (0u == Timeout_Timer_TC_START_SIGNAL_PRESENT) */
    #endif /* (Timeout_Timer__TIMER == Timeout_Timer_CONFIG) */
}


/*******************************************************************************
* Function Name: Timeout_Timer_Start
********************************************************************************
*
* Summary:
*  Initialize the Timeout_Timer with default customizer
*  values when called the first time and enables the Timeout_Timer.
*  For subsequent calls the configuration is left unchanged and the component is
*  just enabled.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  Timeout_Timer_initVar: global variable is used to indicate initial
*  configuration of this component.  The variable is initialized to zero and set
*  to 1 the first time Timeout_Timer_Start() is called. This allows
*  enable/disable component without re-initialization in all subsequent calls
*  to the Timeout_Timer_Start() routine.
*
*******************************************************************************/
void Timeout_Timer_Start(void)
{
    if (0u == Timeout_Timer_initVar)
    {
        Timeout_Timer_Init();
        Timeout_Timer_initVar = 1u;
    }

    Timeout_Timer_Enable();
}


/*******************************************************************************
* Function Name: Timeout_Timer_Stop
********************************************************************************
*
* Summary:
*  Disables the Timeout_Timer.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_Stop(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_BLOCK_CONTROL_REG &= (uint32)~Timeout_Timer_MASK;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetMode
********************************************************************************
*
* Summary:
*  Sets the operation mode of the Timeout_Timer. This function is used when
*  configured as a generic Timeout_Timer and the actual mode of operation is
*  set at runtime. The mode must be set while the component is disabled.
*
* Parameters:
*  mode: Mode for the Timeout_Timer to operate in
*   Values:
*   - Timeout_Timer_MODE_TIMER_COMPARE - Timer / Counter with
*                                                 compare capability
*         - Timeout_Timer_MODE_TIMER_CAPTURE - Timer / Counter with
*                                                 capture capability
*         - Timeout_Timer_MODE_QUAD - Quadrature decoder
*         - Timeout_Timer_MODE_PWM - PWM
*         - Timeout_Timer_MODE_PWM_DT - PWM with dead time
*         - Timeout_Timer_MODE_PWM_PR - PWM with pseudo random capability
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetMode(uint32 mode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_CONTROL_REG &= (uint32)~Timeout_Timer_MODE_MASK;
    Timeout_Timer_CONTROL_REG |= mode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetQDMode
********************************************************************************
*
* Summary:
*  Sets the the Quadrature Decoder to one of 3 supported modes.
*  Is functionality is only applicable to Quadrature Decoder operation.
*
* Parameters:
*  qdMode: Quadrature Decoder mode
*   Values:
*         - Timeout_Timer_MODE_X1 - Counts on phi 1 rising
*         - Timeout_Timer_MODE_X2 - Counts on both edges of phi1 (2x faster)
*         - Timeout_Timer_MODE_X4 - Counts on both edges of phi1 and phi2
*                                        (4x faster)
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetQDMode(uint32 qdMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_CONTROL_REG &= (uint32)~Timeout_Timer_QUAD_MODE_MASK;
    Timeout_Timer_CONTROL_REG |= qdMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetPrescaler
********************************************************************************
*
* Summary:
*  Sets the prescaler value that is applied to the clock input.  Not applicable
*  to PWM with dead time mode or Quadrature Decoder mode.
*
* Parameters:
*  prescaler: Prescaler divider value
*   Values:
*         - Timeout_Timer_PRESCALE_DIVBY1    - Divide by 1 (no prescaling)
*         - Timeout_Timer_PRESCALE_DIVBY2    - Divide by 2
*         - Timeout_Timer_PRESCALE_DIVBY4    - Divide by 4
*         - Timeout_Timer_PRESCALE_DIVBY8    - Divide by 8
*         - Timeout_Timer_PRESCALE_DIVBY16   - Divide by 16
*         - Timeout_Timer_PRESCALE_DIVBY32   - Divide by 32
*         - Timeout_Timer_PRESCALE_DIVBY64   - Divide by 64
*         - Timeout_Timer_PRESCALE_DIVBY128  - Divide by 128
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetPrescaler(uint32 prescaler)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_CONTROL_REG &= (uint32)~Timeout_Timer_PRESCALER_MASK;
    Timeout_Timer_CONTROL_REG |= prescaler;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetOneShot
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the Timeout_Timer runs
*  continuously or stops when terminal count is reached.  By default the
*  Timeout_Timer operates in continuous mode.
*
* Parameters:
*  oneShotEnable
*   Values:
*     - 0 - Continuous
*     - 1 - Enable One Shot
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetOneShot(uint32 oneShotEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_CONTROL_REG &= (uint32)~Timeout_Timer_ONESHOT_MASK;
    Timeout_Timer_CONTROL_REG |= ((uint32)((oneShotEnable & Timeout_Timer_1BIT_MASK) <<
                                                               Timeout_Timer_ONESHOT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetPWMMode
********************************************************************************
*
* Summary:
*  Writes the control register that determines what mode of operation the PWM
*  output lines are driven in.  There is a setting for what to do on a
*  comparison match (CC_MATCH), on an overflow (OVERFLOW) and on an underflow
*  (UNDERFLOW).  The value for each of the 3 must be ORed together to form the
*  mode.
*
* Parameters:
*  modeMask: Combination of the 3 mode settings.  Mask must include a value for
*  each of the 3 or use one of the preconfigured PWM settings.
*   Values:
*     - CC_MATCH_SET        - Set on comparison match
*     - CC_MATCH_CLEAR      - Clear on comparison match
*     - CC_MATCH_INVERT     - Invert on comparison match
*     - CC_MATCH_NO_CHANGE  - No change on comparison match
*     - OVERLOW_SET         - Set on overflow
*     - OVERLOW_CLEAR       - Clear on overflow
*     - OVERLOW_INVERT      - Invert on overflow
*     - OVERLOW_NO_CHANGE   - No change on overflow
*     - UNDERFLOW_SET       - Set on underflow
*     - UNDERFLOW_CLEAR     - Clear on underflow
*     - UNDERFLOW_INVERT    - Invert on underflow
*     - UNDERFLOW_NO_CHANGE - No change on underflow
*     - PWM_MODE_LEFT       - Setting for left aligned PWM.  Should be combined
*                             with up counting mode
*     - PWM_MODE_RIGHT      - Setting for right aligned PWM.  Should be combined
*                             with down counting mode
*     - PWM_MODE_CENTER     - Setting for center aligned PWM.  Should be 
*                             combined with up/down 0 mode
*     - PWM_MODE_ASYM       - Setting for asymmetric PWM.  Should be combined
*                             with up/down 1 mode
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetPWMMode(uint32 modeMask)
{
    Timeout_Timer_TRIG_CONTROL2_REG = (modeMask & Timeout_Timer_6BIT_MASK);
}



/*******************************************************************************
* Function Name: Timeout_Timer_SetPWMSyncKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes an asynchronous or synchronous kill operation.  By default the kill
*  operation is asynchronous.  This functionality is only applicable to PWM and
*  PWM with dead time modes.
*
*  For Synchronous mode the kill signal disables both the line and line_n
*  signals until the next terminal count.
*
*  For Asynchronous mode the kill signal disables both the line and line_n
*  signals when the kill signal is present.  This mode should only be used
*  when the kill signal (stop input) is configured in pass through mode
*  (Level sensitive signal).

*
* Parameters:
*  syncKillEnable
*   Values:
*     - 0 - Asynchronous
*     - 1 - Synchronous
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetPWMSyncKill(uint32 syncKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_CONTROL_REG &= (uint32)~Timeout_Timer_PWM_SYNC_KILL_MASK;
    Timeout_Timer_CONTROL_REG |= ((uint32)((syncKillEnable & Timeout_Timer_1BIT_MASK)  <<
                                               Timeout_Timer_PWM_SYNC_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetPWMStopOnKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes the PWM counter to stop.  By default the kill operation does not stop
*  the counter.  This functionality is only applicable to the three PWM modes.
*
*
* Parameters:
*  stopOnKillEnable
*   Values:
*     - 0 - Don't stop
*     - 1 - Stop
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetPWMStopOnKill(uint32 stopOnKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_CONTROL_REG &= (uint32)~Timeout_Timer_PWM_STOP_KILL_MASK;
    Timeout_Timer_CONTROL_REG |= ((uint32)((stopOnKillEnable & Timeout_Timer_1BIT_MASK)  <<
                                                         Timeout_Timer_PWM_STOP_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetPWMDeadTime
********************************************************************************
*
* Summary:
*  Writes the dead time control value.  This value delays the rising edge of
*  both the line and line_n signals the designated number of cycles resulting
*  in both signals being inactive for that many cycles.  This functionality is
*  only applicable to the PWM in dead time mode.

*
* Parameters:
*  Dead time to insert
*   Values: 0 to 255
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetPWMDeadTime(uint32 deadTime)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_CONTROL_REG &= (uint32)~Timeout_Timer_PRESCALER_MASK;
    Timeout_Timer_CONTROL_REG |= ((uint32)((deadTime & Timeout_Timer_8BIT_MASK) <<
                                                          Timeout_Timer_PRESCALER_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetPWMInvert
********************************************************************************
*
* Summary:
*  Writes the bits that control whether the line and line_n outputs are
*  inverted from their normal output values.  This functionality is only
*  applicable to the three PWM modes.
*
* Parameters:
*  mask: Mask of outputs to invert.
*   Values:
*         - Timeout_Timer_INVERT_LINE   - Inverts the line output
*         - Timeout_Timer_INVERT_LINE_N - Inverts the line_n output
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetPWMInvert(uint32 mask)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_CONTROL_REG &= (uint32)~Timeout_Timer_INV_OUT_MASK;
    Timeout_Timer_CONTROL_REG |= mask;

    CyExitCriticalSection(enableInterrupts);
}



/*******************************************************************************
* Function Name: Timeout_Timer_WriteCounter
********************************************************************************
*
* Summary:
*  Writes a new 16bit counter value directly into the counter register, thus
*  setting the counter (not the period) to the value written. It is not
*  advised to write to this field when the counter is running.
*
* Parameters:
*  count: value to write
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_WriteCounter(uint32 count)
{
    Timeout_Timer_COUNTER_REG = (count & Timeout_Timer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Timeout_Timer_ReadCounter
********************************************************************************
*
* Summary:
*  Reads the current counter value.
*
* Parameters:
*  None
*
* Return:
*  Current counter value
*
*******************************************************************************/
uint32 Timeout_Timer_ReadCounter(void)
{
    return (Timeout_Timer_COUNTER_REG & Timeout_Timer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetCounterMode
********************************************************************************
*
* Summary:
*  Sets the counter mode.  Applicable to all modes except Quadrature Decoder
*  and PWM with pseudo random output.
*
* Parameters:
*  counterMode: Enumerated couner type values
*   Values:
*     - Timeout_Timer_COUNT_UP       - Counts up
*     - Timeout_Timer_COUNT_DOWN     - Counts down
*     - Timeout_Timer_COUNT_UPDOWN0  - Counts up and down. Terminal count
*                                         generated when counter reaches 0
*     - Timeout_Timer_COUNT_UPDOWN1  - Counts up and down. Terminal count
*                                         generated both when counter reaches 0
*                                         and period
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetCounterMode(uint32 counterMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_CONTROL_REG &= (uint32)~Timeout_Timer_UPDOWN_MASK;
    Timeout_Timer_CONTROL_REG |= counterMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_WritePeriod
********************************************************************************
*
* Summary:
*  Writes the 16 bit period register with the new period value.
*  To cause the counter to count for N cycles this register should be written
*  with N-1 (counts from 0 to period inclusive).
*
* Parameters:
*  period: Period value
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_WritePeriod(uint32 period)
{
    Timeout_Timer_PERIOD_REG = (period & Timeout_Timer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Timeout_Timer_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the 16 bit period register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 Timeout_Timer_ReadPeriod(void)
{
    return (Timeout_Timer_PERIOD_REG & Timeout_Timer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetCompareSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the compare registers are
*  swapped. When enabled in Timer/Counter mode(without capture) the swap occurs
*  at a TC event. In PWM mode the swap occurs at the next TC event following
*  a hardware switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetCompareSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_CONTROL_REG &= (uint32)~Timeout_Timer_RELOAD_CC_MASK;
    Timeout_Timer_CONTROL_REG |= (swapEnable & Timeout_Timer_1BIT_MASK);

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_WritePeriodBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit period buf register with the new period value.
*
* Parameters:
*  periodBuf: Period value
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_WritePeriodBuf(uint32 periodBuf)
{
    Timeout_Timer_PERIOD_BUF_REG = (periodBuf & Timeout_Timer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Timeout_Timer_ReadPeriodBuf
********************************************************************************
*
* Summary:
*  Reads the 16 bit period buf register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 Timeout_Timer_ReadPeriodBuf(void)
{
    return (Timeout_Timer_PERIOD_BUF_REG & Timeout_Timer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetPeriodSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the period registers are
*  swapped. When enabled in Timer/Counter mode the swap occurs at a TC event.
*  In PWM mode the swap occurs at the next TC event following a hardware switch
*  event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetPeriodSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_CONTROL_REG &= (uint32)~Timeout_Timer_RELOAD_PERIOD_MASK;
    Timeout_Timer_CONTROL_REG |= ((uint32)((swapEnable & Timeout_Timer_1BIT_MASK) <<
                                                            Timeout_Timer_RELOAD_PERIOD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_WriteCompare
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compare: Compare value
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_WriteCompare(uint32 compare)
{
    Timeout_Timer_COMP_CAP_REG = (compare & Timeout_Timer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Timeout_Timer_ReadCompare
********************************************************************************
*
* Summary:
*  Reads the compare register. Not applicable for Timer/Counter with Capture
*  or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare value
*
*******************************************************************************/
uint32 Timeout_Timer_ReadCompare(void)
{
    return (Timeout_Timer_COMP_CAP_REG & Timeout_Timer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Timeout_Timer_WriteCompareBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare buffer register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compareBuf: Compare value
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_WriteCompareBuf(uint32 compareBuf)
{
   Timeout_Timer_COMP_CAP_BUF_REG = (compareBuf & Timeout_Timer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Timeout_Timer_ReadCompareBuf
********************************************************************************
*
* Summary:
*  Reads the compare buffer register. Not applicable for Timer/Counter with
*  Capture or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare buffer value
*
*******************************************************************************/
uint32 Timeout_Timer_ReadCompareBuf(void)
{
    return (Timeout_Timer_COMP_CAP_BUF_REG & Timeout_Timer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Timeout_Timer_ReadCapture
********************************************************************************
*
* Summary:
*  Reads the captured counter value. This API is applicable only for
*  Timer/Counter with capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture value
*
*******************************************************************************/
uint32 Timeout_Timer_ReadCapture(void)
{
    return (Timeout_Timer_COMP_CAP_REG & Timeout_Timer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Timeout_Timer_ReadCaptureBuf
********************************************************************************
*
* Summary:
*  Reads the capture buffer register. This API is applicable only for
*  Timer/Counter with capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture buffer value
*
*******************************************************************************/
uint32 Timeout_Timer_ReadCaptureBuf(void)
{
    return (Timeout_Timer_COMP_CAP_BUF_REG & Timeout_Timer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetCaptureMode
********************************************************************************
*
* Summary:
*  Sets the capture trigger mode. For PWM mode this is the switch input.
*  This input is not applicable to the Timer/Counter without Capture and
*  Quadrature Decoder modes.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - Timeout_Timer_TRIG_LEVEL     - Level
*     - Timeout_Timer_TRIG_RISING    - Rising edge
*     - Timeout_Timer_TRIG_FALLING   - Falling edge
*     - Timeout_Timer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetCaptureMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_TRIG_CONTROL1_REG &= (uint32)~Timeout_Timer_CAPTURE_MASK;
    Timeout_Timer_TRIG_CONTROL1_REG |= triggerMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetReloadMode
********************************************************************************
*
* Summary:
*  Sets the reload trigger mode. For Quadrature Decoder mode this is the index
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - Timeout_Timer_TRIG_LEVEL     - Level
*     - Timeout_Timer_TRIG_RISING    - Rising edge
*     - Timeout_Timer_TRIG_FALLING   - Falling edge
*     - Timeout_Timer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetReloadMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_TRIG_CONTROL1_REG &= (uint32)~Timeout_Timer_RELOAD_MASK;
    Timeout_Timer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << Timeout_Timer_RELOAD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetStartMode
********************************************************************************
*
* Summary:
*  Sets the start trigger mode. For Quadrature Decoder mode this is the
*  phiB input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - Timeout_Timer_TRIG_LEVEL     - Level
*     - Timeout_Timer_TRIG_RISING    - Rising edge
*     - Timeout_Timer_TRIG_FALLING   - Falling edge
*     - Timeout_Timer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetStartMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_TRIG_CONTROL1_REG &= (uint32)~Timeout_Timer_START_MASK;
    Timeout_Timer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << Timeout_Timer_START_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetStopMode
********************************************************************************
*
* Summary:
*  Sets the stop trigger mode. For PWM mode this is the kill input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - Timeout_Timer_TRIG_LEVEL     - Level
*     - Timeout_Timer_TRIG_RISING    - Rising edge
*     - Timeout_Timer_TRIG_FALLING   - Falling edge
*     - Timeout_Timer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetStopMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_TRIG_CONTROL1_REG &= (uint32)~Timeout_Timer_STOP_MASK;
    Timeout_Timer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << Timeout_Timer_STOP_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetCountMode
********************************************************************************
*
* Summary:
*  Sets the count trigger mode. For Quadrature Decoder mode this is the phiA
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - Timeout_Timer_TRIG_LEVEL     - Level
*     - Timeout_Timer_TRIG_RISING    - Rising edge
*     - Timeout_Timer_TRIG_FALLING   - Falling edge
*     - Timeout_Timer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetCountMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_TRIG_CONTROL1_REG &= (uint32)~Timeout_Timer_COUNT_MASK;
    Timeout_Timer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << Timeout_Timer_COUNT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_TriggerCommand
********************************************************************************
*
* Summary:
*  Triggers the designated command to occur on the designated TCPWM instances.
*  The mask can be used to apply this command simultaneously to more than one
*  instance.  This allows multiple TCPWM instances to be synchronized.
*
* Parameters:
*  mask: Combination of mask bits for each instance of the TCPWM that the
*        command should apply to.  This function from one instance can be used
*        to apply the command to any of the instances in the design.
*        The mask value for a specific instance is available with the MASK
*        define.
*  command: Enumerated command values. Capture command only applicable for
*           Timer/Counter with Capture and PWM modes.
*   Values:
*     - Timeout_Timer_CMD_CAPTURE    - Trigger Capture command
*     - Timeout_Timer_CMD_RELOAD     - Trigger Reload command
*     - Timeout_Timer_CMD_STOP       - Trigger Stop command
*     - Timeout_Timer_CMD_START      - Trigger Start command
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_TriggerCommand(uint32 mask, uint32 command)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Timeout_Timer_COMMAND_REG = ((uint32)(mask << command));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Timeout_Timer_ReadStatus
********************************************************************************
*
* Summary:
*  Reads the status of the Timeout_Timer.
*
* Parameters:
*  None
*
* Return:
*  Status
*   Values:
*     - Timeout_Timer_STATUS_DOWN    - Set if counting down
*     - Timeout_Timer_STATUS_RUNNING - Set if counter is running
*
*******************************************************************************/
uint32 Timeout_Timer_ReadStatus(void)
{
    return ((Timeout_Timer_STATUS_REG >> Timeout_Timer_RUNNING_STATUS_SHIFT) |
            (Timeout_Timer_STATUS_REG & Timeout_Timer_STATUS_DOWN));
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetInterruptMode
********************************************************************************
*
* Summary:
*  Sets the interrupt mask to control which interrupt
*  requests generate the interrupt signal.
*
* Parameters:
*   interruptMask: Mask of bits to be enabled
*   Values:
*     - Timeout_Timer_INTR_MASK_TC       - Terminal count mask
*     - Timeout_Timer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetInterruptMode(uint32 interruptMask)
{
    Timeout_Timer_INTERRUPT_MASK_REG =  interruptMask;
}


/*******************************************************************************
* Function Name: Timeout_Timer_GetInterruptSourceMasked
********************************************************************************
*
* Summary:
*  Gets the interrupt requests masked by the interrupt mask.
*
* Parameters:
*   None
*
* Return:
*  Masked interrupt source
*   Values:
*     - Timeout_Timer_INTR_MASK_TC       - Terminal count mask
*     - Timeout_Timer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 Timeout_Timer_GetInterruptSourceMasked(void)
{
    return (Timeout_Timer_INTERRUPT_MASKED_REG);
}


/*******************************************************************************
* Function Name: Timeout_Timer_GetInterruptSource
********************************************************************************
*
* Summary:
*  Gets the interrupt requests (without masking).
*
* Parameters:
*  None
*
* Return:
*  Interrupt request value
*   Values:
*     - Timeout_Timer_INTR_MASK_TC       - Terminal count mask
*     - Timeout_Timer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 Timeout_Timer_GetInterruptSource(void)
{
    return (Timeout_Timer_INTERRUPT_REQ_REG);
}


/*******************************************************************************
* Function Name: Timeout_Timer_ClearInterrupt
********************************************************************************
*
* Summary:
*  Clears the interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to clear
*   Values:
*     - Timeout_Timer_INTR_MASK_TC       - Terminal count mask
*     - Timeout_Timer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_ClearInterrupt(uint32 interruptMask)
{
    Timeout_Timer_INTERRUPT_REQ_REG = interruptMask;
}


/*******************************************************************************
* Function Name: Timeout_Timer_SetInterrupt
********************************************************************************
*
* Summary:
*  Sets a software interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to set
*   Values:
*     - Timeout_Timer_INTR_MASK_TC       - Terminal count mask
*     - Timeout_Timer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void Timeout_Timer_SetInterrupt(uint32 interruptMask)
{
    Timeout_Timer_INTERRUPT_SET_REG = interruptMask;
}


/* [] END OF FILE */
