/*******************************************************************************
* File Name: Timeout_Timer.h
* Version 1.0
*
* Description:
*  This file provides constants and parameter values for the Timeout_Timer
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_Timeout_Timer_H)
#define CY_TCPWM_Timeout_Timer_H

#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} Timeout_Timer_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  Timeout_Timer_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

/* TCPWM Configuration */
#define Timeout_Timer_CONFIG                         (1lu)

/* Quad Mode */
/* Parameters */
#define Timeout_Timer_QUAD_ENCODING_MODES            (0lu)

/* Signal modes */
#define Timeout_Timer_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define Timeout_Timer_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define Timeout_Timer_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define Timeout_Timer_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define Timeout_Timer_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define Timeout_Timer_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define Timeout_Timer_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define Timeout_Timer_TC_RUN_MODE                    (0lu)
#define Timeout_Timer_TC_COUNTER_MODE                (1lu)
#define Timeout_Timer_TC_COMP_CAP_MODE               (0lu)
#define Timeout_Timer_TC_PRESCALER                   (0lu)

/* Signal modes */
#define Timeout_Timer_TC_RELOAD_SIGNAL_MODE          (0lu)
#define Timeout_Timer_TC_COUNT_SIGNAL_MODE           (3lu)
#define Timeout_Timer_TC_START_SIGNAL_MODE           (0lu)
#define Timeout_Timer_TC_STOP_SIGNAL_MODE            (0lu)
#define Timeout_Timer_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define Timeout_Timer_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define Timeout_Timer_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define Timeout_Timer_TC_START_SIGNAL_PRESENT        (0lu)
#define Timeout_Timer_TC_STOP_SIGNAL_PRESENT         (0lu)
#define Timeout_Timer_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define Timeout_Timer_TC_INTERRUPT_MASK              (2lu)

/* PWM Mode */
/* Parameters */
#define Timeout_Timer_PWM_KILL_EVENT                 (0lu)
#define Timeout_Timer_PWM_STOP_EVENT                 (0lu)
#define Timeout_Timer_PWM_MODE                       (4lu)
#define Timeout_Timer_PWM_OUT_N_INVERT               (0lu)
#define Timeout_Timer_PWM_OUT_INVERT                 (0lu)
#define Timeout_Timer_PWM_ALIGN                      (0lu)
#define Timeout_Timer_PWM_RUN_MODE                   (0lu)
#define Timeout_Timer_PWM_DEAD_TIME_CYCLE            (0lu)
#define Timeout_Timer_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define Timeout_Timer_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define Timeout_Timer_PWM_COUNT_SIGNAL_MODE          (3lu)
#define Timeout_Timer_PWM_START_SIGNAL_MODE          (0lu)
#define Timeout_Timer_PWM_STOP_SIGNAL_MODE           (0lu)
#define Timeout_Timer_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define Timeout_Timer_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define Timeout_Timer_PWM_COUNT_SIGNAL_PRESENT       (0lu)
#define Timeout_Timer_PWM_START_SIGNAL_PRESENT       (0lu)
#define Timeout_Timer_PWM_STOP_SIGNAL_PRESENT        (0lu)
#define Timeout_Timer_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define Timeout_Timer_PWM_INTERRUPT_MASK             (1lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define Timeout_Timer_TC_PERIOD_VALUE                (100lu)
#define Timeout_Timer_TC_COMPARE_VALUE               (0lu)
#define Timeout_Timer_TC_COMPARE_BUF_VALUE           (65535lu)
#define Timeout_Timer_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define Timeout_Timer_PWM_PERIOD_VALUE               (65535lu)
#define Timeout_Timer_PWM_PERIOD_BUF_VALUE           (65535lu)
#define Timeout_Timer_PWM_PERIOD_SWAP                (0lu)
#define Timeout_Timer_PWM_COMPARE_VALUE              (65535lu)
#define Timeout_Timer_PWM_COMPARE_BUF_VALUE          (65535lu)
#define Timeout_Timer_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define Timeout_Timer__LEFT 0
#define Timeout_Timer__RIGHT 1
#define Timeout_Timer__CENTER 2
#define Timeout_Timer__ASYMMETRIC 3

#define Timeout_Timer__X1 0
#define Timeout_Timer__X2 1
#define Timeout_Timer__X4 2

#define Timeout_Timer__PWM 4
#define Timeout_Timer__PWM_DT 5
#define Timeout_Timer__PWM_PR 6

#define Timeout_Timer__INVERSE 1
#define Timeout_Timer__DIRECT 0

#define Timeout_Timer__CAPTURE 2
#define Timeout_Timer__COMPARE 0

#define Timeout_Timer__TRIG_LEVEL 3
#define Timeout_Timer__TRIG_RISING 0
#define Timeout_Timer__TRIG_FALLING 1
#define Timeout_Timer__TRIG_BOTH 2

#define Timeout_Timer__INTR_MASK_TC 1
#define Timeout_Timer__INTR_MASK_CC_MATCH 2
#define Timeout_Timer__INTR_MASK_NONE 0
#define Timeout_Timer__INTR_MASK_TC_CC 3

#define Timeout_Timer__UNCONFIG 8
#define Timeout_Timer__TIMER 1
#define Timeout_Timer__QUAD 3
#define Timeout_Timer__PWM_SEL 7

#define Timeout_Timer__COUNT_UP 0
#define Timeout_Timer__COUNT_DOWN 1
#define Timeout_Timer__COUNT_UPDOWN0 2
#define Timeout_Timer__COUNT_UPDOWN1 3


/* Prescaler */
#define Timeout_Timer_PRESCALE_DIVBY1                ((uint32)(0u << Timeout_Timer_PRESCALER_SHIFT))
#define Timeout_Timer_PRESCALE_DIVBY2                ((uint32)(1u << Timeout_Timer_PRESCALER_SHIFT))
#define Timeout_Timer_PRESCALE_DIVBY4                ((uint32)(2u << Timeout_Timer_PRESCALER_SHIFT))
#define Timeout_Timer_PRESCALE_DIVBY8                ((uint32)(3u << Timeout_Timer_PRESCALER_SHIFT))
#define Timeout_Timer_PRESCALE_DIVBY16               ((uint32)(4u << Timeout_Timer_PRESCALER_SHIFT))
#define Timeout_Timer_PRESCALE_DIVBY32               ((uint32)(5u << Timeout_Timer_PRESCALER_SHIFT))
#define Timeout_Timer_PRESCALE_DIVBY64               ((uint32)(6u << Timeout_Timer_PRESCALER_SHIFT))
#define Timeout_Timer_PRESCALE_DIVBY128              ((uint32)(7u << Timeout_Timer_PRESCALER_SHIFT))

/* TCPWM set modes */
#define Timeout_Timer_MODE_TIMER_COMPARE             ((uint32)(Timeout_Timer__COMPARE         <<  \
                                                                  Timeout_Timer_MODE_SHIFT))
#define Timeout_Timer_MODE_TIMER_CAPTURE             ((uint32)(Timeout_Timer__CAPTURE         <<  \
                                                                  Timeout_Timer_MODE_SHIFT))
#define Timeout_Timer_MODE_QUAD                      ((uint32)(Timeout_Timer__QUAD            <<  \
                                                                  Timeout_Timer_MODE_SHIFT))
#define Timeout_Timer_MODE_PWM                       ((uint32)(Timeout_Timer__PWM             <<  \
                                                                  Timeout_Timer_MODE_SHIFT))
#define Timeout_Timer_MODE_PWM_DT                    ((uint32)(Timeout_Timer__PWM_DT          <<  \
                                                                  Timeout_Timer_MODE_SHIFT))
#define Timeout_Timer_MODE_PWM_PR                    ((uint32)(Timeout_Timer__PWM_PR          <<  \
                                                                  Timeout_Timer_MODE_SHIFT))

/* Quad Modes */
#define Timeout_Timer_MODE_X1                        ((uint32)(Timeout_Timer__X1              <<  \
                                                                  Timeout_Timer_QUAD_MODE_SHIFT))
#define Timeout_Timer_MODE_X2                        ((uint32)(Timeout_Timer__X2              <<  \
                                                                  Timeout_Timer_QUAD_MODE_SHIFT))
#define Timeout_Timer_MODE_X4                        ((uint32)(Timeout_Timer__X4              <<  \
                                                                  Timeout_Timer_QUAD_MODE_SHIFT))

/* Counter modes */
#define Timeout_Timer_COUNT_UP                       ((uint32)(Timeout_Timer__COUNT_UP        <<  \
                                                                  Timeout_Timer_UPDOWN_SHIFT))
#define Timeout_Timer_COUNT_DOWN                     ((uint32)(Timeout_Timer__COUNT_DOWN      <<  \
                                                                  Timeout_Timer_UPDOWN_SHIFT))
#define Timeout_Timer_COUNT_UPDOWN0                  ((uint32)(Timeout_Timer__COUNT_UPDOWN0   <<  \
                                                                  Timeout_Timer_UPDOWN_SHIFT))
#define Timeout_Timer_COUNT_UPDOWN1                  ((uint32)(Timeout_Timer__COUNT_UPDOWN1   <<  \
                                                                  Timeout_Timer_UPDOWN_SHIFT))

/* PWM output invert */
#define Timeout_Timer_INVERT_LINE                    ((uint32)(Timeout_Timer__INVERSE         <<  \
                                                                  Timeout_Timer_INV_OUT_SHIFT))
#define Timeout_Timer_INVERT_LINE_N                  ((uint32)(Timeout_Timer__INVERSE         <<  \
                                                                  Timeout_Timer_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define Timeout_Timer_TRIG_RISING                    (Timeout_Timer__TRIG_RISING)
#define Timeout_Timer_TRIG_FALLING                   (Timeout_Timer__TRIG_FALLING)
#define Timeout_Timer_TRIG_BOTH                      (Timeout_Timer__TRIG_BOTH)
#define Timeout_Timer_TRIG_LEVEL                     (Timeout_Timer__TRIG_LEVEL)

/* Interrupt mask */
#define Timeout_Timer_INTR_MASK_TC                   (Timeout_Timer__INTR_MASK_TC)
#define Timeout_Timer_INTR_MASK_CC_MATCH             (Timeout_Timer__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define Timeout_Timer_CC_MATCH_SET                   (0x00u)
#define Timeout_Timer_CC_MATCH_CLEAR                 (0x01u)
#define Timeout_Timer_CC_MATCH_INVERT                (0x02u)
#define Timeout_Timer_CC_MATCH_NO_CHANGE             (0x03u)
#define Timeout_Timer_OVERLOW_SET                    (0x00u)
#define Timeout_Timer_OVERLOW_CLEAR                  (0x04u)
#define Timeout_Timer_OVERLOW_INVERT                 (0x08u)
#define Timeout_Timer_OVERLOW_NO_CHANGE              (0x0Cu)
#define Timeout_Timer_UNDERFLOW_SET                  (0x00u)
#define Timeout_Timer_UNDERFLOW_CLEAR                (0x10u)
#define Timeout_Timer_UNDERFLOW_INVERT               (0x20u)
#define Timeout_Timer_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define Timeout_Timer_PWM_MODE_LEFT                  (Timeout_Timer_CC_MATCH_CLEAR        |   \
                                                         Timeout_Timer_OVERLOW_SET           |   \
                                                         Timeout_Timer_UNDERFLOW_NO_CHANGE)
#define Timeout_Timer_PWM_MODE_RIGHT                 (Timeout_Timer_CC_MATCH_SET          |   \
                                                         Timeout_Timer_OVERLOW_NO_CHANGE     |   \
                                                         Timeout_Timer_UNDERFLOW_CLEAR)
#define Timeout_Timer_PWM_MODE_CENTER                (Timeout_Timer_CC_MATCH_INVERT       |   \
                                                         Timeout_Timer_OVERLOW_NO_CHANGE     |   \
                                                         Timeout_Timer_UNDERFLOW_CLEAR)
#define Timeout_Timer_PWM_MODE_ASYM                  (Timeout_Timer_CC_MATCH_NO_CHANGE    |   \
                                                         Timeout_Timer_OVERLOW_SET           |   \
                                                         Timeout_Timer_UNDERFLOW_CLEAR )

/* Command operations without condition */
#define Timeout_Timer_CMD_CAPTURE                    (0u)
#define Timeout_Timer_CMD_RELOAD                     (8u)
#define Timeout_Timer_CMD_STOP                       (16u)
#define Timeout_Timer_CMD_START                      (24u)

/* Status */
#define Timeout_Timer_STATUS_DOWN                    (1u)
#define Timeout_Timer_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   Timeout_Timer_Init(void);
void   Timeout_Timer_Enable(void);
void   Timeout_Timer_Start(void);
void   Timeout_Timer_Stop(void);

void   Timeout_Timer_SetMode(uint32 mode);
void   Timeout_Timer_SetCounterMode(uint32 counterMode);
void   Timeout_Timer_SetPWMMode(uint32 modeMask);
void   Timeout_Timer_SetQDMode(uint32 qdMode);

void   Timeout_Timer_SetPrescaler(uint32 prescaler);
void   Timeout_Timer_TriggerCommand(uint32 mask, uint32 command);
void   Timeout_Timer_SetOneShot(uint32 oneShotEnable);
uint32 Timeout_Timer_ReadStatus(void);

void   Timeout_Timer_SetPWMSyncKill(uint32 syncKillEnable);
void   Timeout_Timer_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   Timeout_Timer_SetPWMDeadTime(uint32 deadTime);
void   Timeout_Timer_SetPWMInvert(uint32 mask);

void   Timeout_Timer_SetInterruptMode(uint32 interruptMask);
uint32 Timeout_Timer_GetInterruptSourceMasked(void);
uint32 Timeout_Timer_GetInterruptSource(void);
void   Timeout_Timer_ClearInterrupt(uint32 interruptMask);
void   Timeout_Timer_SetInterrupt(uint32 interruptMask);

void   Timeout_Timer_WriteCounter(uint32 count);
uint32 Timeout_Timer_ReadCounter(void);

uint32 Timeout_Timer_ReadCapture(void);
uint32 Timeout_Timer_ReadCaptureBuf(void);

void   Timeout_Timer_WritePeriod(uint32 period);
uint32 Timeout_Timer_ReadPeriod(void);
void   Timeout_Timer_WritePeriodBuf(uint32 periodBuf);
uint32 Timeout_Timer_ReadPeriodBuf(void);

void   Timeout_Timer_WriteCompare(uint32 compare);
uint32 Timeout_Timer_ReadCompare(void);
void   Timeout_Timer_WriteCompareBuf(uint32 compareBuf);
uint32 Timeout_Timer_ReadCompareBuf(void);

void   Timeout_Timer_SetPeriodSwap(uint32 swapEnable);
void   Timeout_Timer_SetCompareSwap(uint32 swapEnable);

void   Timeout_Timer_SetCaptureMode(uint32 triggerMode);
void   Timeout_Timer_SetReloadMode(uint32 triggerMode);
void   Timeout_Timer_SetStartMode(uint32 triggerMode);
void   Timeout_Timer_SetStopMode(uint32 triggerMode);
void   Timeout_Timer_SetCountMode(uint32 triggerMode);

void   Timeout_Timer_SaveConfig(void);
void   Timeout_Timer_RestoreConfig(void);
void   Timeout_Timer_Sleep(void);
void   Timeout_Timer_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define Timeout_Timer_BLOCK_CONTROL_REG              (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define Timeout_Timer_BLOCK_CONTROL_PTR              ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define Timeout_Timer_COMMAND_REG                    (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define Timeout_Timer_COMMAND_PTR                    ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define Timeout_Timer_INTRRUPT_CAUSE_REG             (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define Timeout_Timer_INTRRUPT_CAUSE_PTR             ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define Timeout_Timer_CONTROL_REG                    (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__CTRL )
#define Timeout_Timer_CONTROL_PTR                    ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__CTRL )
#define Timeout_Timer_STATUS_REG                     (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__STATUS )
#define Timeout_Timer_STATUS_PTR                     ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__STATUS )
#define Timeout_Timer_COUNTER_REG                    (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__COUNTER )
#define Timeout_Timer_COUNTER_PTR                    ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__COUNTER )
#define Timeout_Timer_COMP_CAP_REG                   (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__CC )
#define Timeout_Timer_COMP_CAP_PTR                   ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__CC )
#define Timeout_Timer_COMP_CAP_BUF_REG               (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__CC_BUFF )
#define Timeout_Timer_COMP_CAP_BUF_PTR               ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__CC_BUFF )
#define Timeout_Timer_PERIOD_REG                     (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__PERIOD )
#define Timeout_Timer_PERIOD_PTR                     ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__PERIOD )
#define Timeout_Timer_PERIOD_BUF_REG                 (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define Timeout_Timer_PERIOD_BUF_PTR                 ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define Timeout_Timer_TRIG_CONTROL0_REG              (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define Timeout_Timer_TRIG_CONTROL0_PTR              ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define Timeout_Timer_TRIG_CONTROL1_REG              (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define Timeout_Timer_TRIG_CONTROL1_PTR              ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define Timeout_Timer_TRIG_CONTROL2_REG              (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define Timeout_Timer_TRIG_CONTROL2_PTR              ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define Timeout_Timer_INTERRUPT_REQ_REG              (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__INTR )
#define Timeout_Timer_INTERRUPT_REQ_PTR              ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__INTR )
#define Timeout_Timer_INTERRUPT_SET_REG              (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__INTR_SET )
#define Timeout_Timer_INTERRUPT_SET_PTR              ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__INTR_SET )
#define Timeout_Timer_INTERRUPT_MASK_REG             (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__INTR_MASK )
#define Timeout_Timer_INTERRUPT_MASK_PTR             ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__INTR_MASK )
#define Timeout_Timer_INTERRUPT_MASKED_REG           (*(reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__INTR_MASKED )
#define Timeout_Timer_INTERRUPT_MASKED_PTR           ( (reg32 *) Timeout_Timer_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define Timeout_Timer_MASK                           ((uint32)Timeout_Timer_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define Timeout_Timer_RELOAD_CC_SHIFT                (0u)
#define Timeout_Timer_RELOAD_PERIOD_SHIFT            (1u)
#define Timeout_Timer_PWM_SYNC_KILL_SHIFT            (2u)
#define Timeout_Timer_PWM_STOP_KILL_SHIFT            (3u)
#define Timeout_Timer_PRESCALER_SHIFT                (8u)
#define Timeout_Timer_UPDOWN_SHIFT                   (16u)
#define Timeout_Timer_ONESHOT_SHIFT                  (18u)
#define Timeout_Timer_QUAD_MODE_SHIFT                (20u)
#define Timeout_Timer_INV_OUT_SHIFT                  (20u)
#define Timeout_Timer_INV_COMPL_OUT_SHIFT            (21u)
#define Timeout_Timer_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define Timeout_Timer_RELOAD_CC_MASK                 ((uint32)(Timeout_Timer_1BIT_MASK        <<  \
                                                                            Timeout_Timer_RELOAD_CC_SHIFT))
#define Timeout_Timer_RELOAD_PERIOD_MASK             ((uint32)(Timeout_Timer_1BIT_MASK        <<  \
                                                                            Timeout_Timer_RELOAD_PERIOD_SHIFT))
#define Timeout_Timer_PWM_SYNC_KILL_MASK             ((uint32)(Timeout_Timer_1BIT_MASK        <<  \
                                                                            Timeout_Timer_PWM_SYNC_KILL_SHIFT))
#define Timeout_Timer_PWM_STOP_KILL_MASK             ((uint32)(Timeout_Timer_1BIT_MASK        <<  \
                                                                            Timeout_Timer_PWM_STOP_KILL_SHIFT))
#define Timeout_Timer_PRESCALER_MASK                 ((uint32)(Timeout_Timer_8BIT_MASK        <<  \
                                                                            Timeout_Timer_PRESCALER_SHIFT))
#define Timeout_Timer_UPDOWN_MASK                    ((uint32)(Timeout_Timer_2BIT_MASK        <<  \
                                                                            Timeout_Timer_UPDOWN_SHIFT))
#define Timeout_Timer_ONESHOT_MASK                   ((uint32)(Timeout_Timer_1BIT_MASK        <<  \
                                                                            Timeout_Timer_ONESHOT_SHIFT))
#define Timeout_Timer_QUAD_MODE_MASK                 ((uint32)(Timeout_Timer_3BIT_MASK        <<  \
                                                                            Timeout_Timer_QUAD_MODE_SHIFT))
#define Timeout_Timer_INV_OUT_MASK                   ((uint32)(Timeout_Timer_2BIT_MASK        <<  \
                                                                            Timeout_Timer_INV_OUT_SHIFT))
#define Timeout_Timer_MODE_MASK                      ((uint32)(Timeout_Timer_3BIT_MASK        <<  \
                                                                            Timeout_Timer_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define Timeout_Timer_CAPTURE_SHIFT                  (0u)
#define Timeout_Timer_COUNT_SHIFT                    (2u)
#define Timeout_Timer_RELOAD_SHIFT                   (4u)
#define Timeout_Timer_STOP_SHIFT                     (6u)
#define Timeout_Timer_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define Timeout_Timer_CAPTURE_MASK                   ((uint32)(Timeout_Timer_2BIT_MASK        <<  \
                                                                  Timeout_Timer_CAPTURE_SHIFT))
#define Timeout_Timer_COUNT_MASK                     ((uint32)(Timeout_Timer_2BIT_MASK        <<  \
                                                                  Timeout_Timer_COUNT_SHIFT))
#define Timeout_Timer_RELOAD_MASK                    ((uint32)(Timeout_Timer_2BIT_MASK        <<  \
                                                                  Timeout_Timer_RELOAD_SHIFT))
#define Timeout_Timer_STOP_MASK                      ((uint32)(Timeout_Timer_2BIT_MASK        <<  \
                                                                  Timeout_Timer_STOP_SHIFT))
#define Timeout_Timer_START_MASK                     ((uint32)(Timeout_Timer_2BIT_MASK        <<  \
                                                                  Timeout_Timer_START_SHIFT))

/* MASK */
#define Timeout_Timer_1BIT_MASK                      ((uint32)0x01u)
#define Timeout_Timer_2BIT_MASK                      ((uint32)0x03u)
#define Timeout_Timer_3BIT_MASK                      ((uint32)0x07u)
#define Timeout_Timer_6BIT_MASK                      ((uint32)0x3Fu)
#define Timeout_Timer_8BIT_MASK                      ((uint32)0xFFu)
#define Timeout_Timer_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define Timeout_Timer_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define Timeout_Timer_PWM_PR_INIT_VALUE              (1u)

#endif /* End CY_TCPWM_Timeout_Timer_H */

/* [] END OF FILE */
