/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include <device.h>
#include "main.h"

/* Global Variables */
uint16	 SDIN, SDOUT, L30;
uint16	 Test_Data = 0; 
uint32	 TIMEOUT64_COUNTER = 0;
uint8	 TIMEOUT64_FLAG = FALSE;
uint8    SGPIO_DataFlag = FALSE;
uint16   ADC_Slot[NUMBER_OF_DRIVES] = {0};   /* bit mask for installed drives */
uint8    Installed[NUMBER_OF_DRIVES] = {0};  /* installed drive? True or False */
uint8    DriveBits[NUMBER_OF_DRIVES] = {0};  /* individual bits qty "3" per drive */
uint8    Slot_OCC_ACT = 0;
uint8    Slot_OCC_STAT = 0;


void main()
{
   uint8 Drive = 0;
   uint8 Activity = 0;
   uint8 Status = 0;	
   uint8 StatBits[NUMBER_OF_DRIVES] = {0};
	
   InitializePSoC();
   CyGlobalIntEnable;
   Slot_OCC_STAT = 0xAA;
    
    for(;;)
    {
      CheckIfDrivesInstalled();
		
		if (TIMEOUT64_FLAG)   	/* No bus activity for 64msec */
		{
			TIMEOUT64_FLAG = 0;
			/* Wait for bus activity to resume */
			SGPIO_Target_ResetTimeout();
			while (SGPIO_Target_GetTimeoutStatus()){};
			SGPIO_Target_Start();			/* Re-start the Target because the component is disabled */
			SGPIO_Target_EnableInt();		/* in the INT_1MS ISR upon SGPIO Timeout */
		}	
		
	  /* Get the SGPIO Data Bits "SDOUT", and assign the bits to their proper Drive. */
		if (FALSE != SGPIO_DataFlag)  /* SGPIO data frame ready */
		{
            
		    SGPIO_DataFlag = FALSE;
			DriveBits[DRIVE1] = (uint8)(SDOUT & DRIVE1_MASK);
            DriveBits[DRIVE2] = (uint8)((SDOUT & DRIVE2_MASK) >> 3);
            DriveBits[DRIVE3] = (uint8)((SDOUT & DRIVE3_MASK) >> 6);
            DriveBits[DRIVE4] = (uint8)((SDOUT & DRIVE4_MASK) >> 9);
		}
		
      ///////////////////////// STATUS LEDs ///////////////////////////////////		
      /* For Status LEDs    #define STAT_MASK (0x03) */
		for (Drive = 0; Drive < NUMBER_OF_DRIVES; Drive++)
		{
		   if (0 != Installed[Drive])
		   {
		       /* Get the STATUS bits out of the DRIVE bits */
               StatBits[Drive] = (DriveBits[Drive] & STAT_MASK);  
			   /* if in Locate mode, adjust bits to get 4Hz PWM in StatusControl Register */
			   if (StatBits[Drive] == LOCATE) StatBits[Drive] = LOCATE_MASK;  
			   /* if in Rebuild mode, adjust bits to get 1Hz PWM in StatusControl Register */
			   else if (StatBits[Drive] == REBUILD) StatBits[Drive] = REBUILD_MASK;
		   }	
		   else StatBits[Drive] = 0x00;
		}
		
	  /* Get all status bits in order for a write to the Status Control Register */
		Status = (StatBits[0] | (StatBits[1] << 2) | (StatBits[2] << 4) | (StatBits[3] << 6));
	  /* Set Mux for Status LED blinking */
		StatusControlReg_Write(Status);		
      ////////////////////////////////////////////////////////////////////////		

      ///////////////////////// ACTIVITY LEDs ///////////////////////////////////		
      /* For Activity LEDs  #define ACT_MASK (0x04) */
		if ((0 != (DriveBits[DRIVE1] & ACT_MASK)) && (StatBits[DRIVE1] != FAIL))
		{
		   Activity = (Activity | 0b0001);
		}	
		else Activity = (Activity & 0b1110);
		if ((0 != (DriveBits[DRIVE2] & ACT_MASK)) && (StatBits[DRIVE2] != FAIL))
		{
		   Activity = (Activity | 0b0010);
		}	
		else Activity = (Activity & 0b1101);
		if ((0 != (DriveBits[DRIVE3] & ACT_MASK)) && (StatBits[DRIVE3] != FAIL))
		{
		   Activity = (Activity | 0b0100);
		}	
		else Activity = (Activity & 0b1011);
		if ((0 != (DriveBits[DRIVE4] & ACT_MASK)) && (StatBits[DRIVE4] != FAIL))
		{
		   Activity = (Activity | 0b1000);	
		}	
		else Activity = (Activity & 0b0111);	
		
	  /* Set Mux for Activity LED blinking */
		SGPIOActivityReg_Write(Slot_OCC_ACT & Activity);  
      ////////////////////////////////////////////////////////////////////////		
    }
}
/******************************************************************************
* Function Name: CheckIfDrivesInstalled
*******************************************************************************
*
*  Determines which drives are installed and sets Slot Masks accordingly
*
******************************************************************************/
void CheckIfDrivesInstalled(void)
{
	if (ADC_Slot[0] > 2) 
	{
	    Slot_OCC_ACT = Slot_OCC_ACT & 0b1110;
	    Installed[0] = FALSE;
	}	 
	else 
	{
	    Slot_OCC_ACT = Slot_OCC_ACT | 0b0001;
		Installed[0] = TRUE;
	}	 
 
	if (ADC_Slot[1] > 2) 
	{
		Slot_OCC_ACT = Slot_OCC_ACT & 0b1101;
		Installed[1] = FALSE;		 
	}	 
	else 
	{
	    Slot_OCC_ACT = Slot_OCC_ACT | 0b0010;
		Installed[1] = TRUE;
	}	
		
	if (ADC_Slot[2] > 2) 
	{
		Slot_OCC_ACT = Slot_OCC_ACT & 0b1011;
		Installed[2] = FALSE;			 
	}	 
	else 
	{
	    Slot_OCC_ACT = Slot_OCC_ACT | 0b0100;
		Installed[2] = TRUE;
	}	
		
	if (ADC_Slot[3] > 2) 
	{
		Slot_OCC_ACT = Slot_OCC_ACT & 0b0111;
		Installed[3] = FALSE;			 
	}	 
	else 
	{
	    Slot_OCC_ACT = Slot_OCC_ACT | 0b1000;
		Installed[3] = TRUE;
	}	
}

/**********************************
*    Initialize PSoC
**********************************/
void InitializePSoC(void)
{
    I2C_Start();
	Clock_1_Start();
	Clock_2_Start();
	Clock_3_Start();
	SGPIO_Target_Start();
	SGPIO_Target_EnableInt();
	isrTargetINT_Start();
//	isrTargetINT_SetVector(isr_SGPIO);  /* Set isr_SGPIO function as ISR	*/
	isrTimeout_Start();	
	isrTimeout_SetVector(isr_Timeout);  /* Set isr_Timeout function as ISR */
	PWM_1Hz_Start();
	PWM_4Hz_Start();	
    ADC_Start();
    ADC_IRQ_Enable();	
    ADC_StartConvert();
	Timeout_Timer_Start();
}

/******************************************************************************
* Function Name: ADC_ISR_Handler
*******************************************************************************
*
*  Interrupt Service Routine for ADC
*
******************************************************************************/
CY_ISR(ADC_ISR_Handler)
{
    uint32 intr_status;
   /* Read interrupt status register */
   intr_status = ADC_SAR_INTR_REG;	
    /* Get readings for each channel */
   ADC_Slot[CHANNEL_1] = ADC_SAR_CHAN0_RESULT_REG;
   ADC_Slot[CHANNEL_2] = ADC_SAR_CHAN1_RESULT_REG;
   ADC_Slot[CHANNEL_3] = ADC_SAR_CHAN2_RESULT_REG;
   ADC_Slot[CHANNEL_4] = ADC_SAR_CHAN3_RESULT_REG;	 
    /* Clear handled interrupt */
   ADC_SAR_INTR_REG = intr_status;
}

/******************************************************************************
* Function Name: isrSGPIO
*******************************************************************************
*
*  Interrupt Service Routine for SGPIO interrupt
*
******************************************************************************/
//CY_ISR(isr_SGPIO)
//{
//	/* Read SDOUT data and vendor specific L3:0 data from the Rx FIFO */
//	SDOUT = SGPIO_Target_ReadRxData();
//	L30   = SGPIO_Target_ReadRxData();
//	/* Send back whatever was received for transmission out on SDIN next frame */
//	SGPIO_Target_WriteTxData(SDOUT); 
//	SGPIO_DataFlag = TRUE;
//	SGPIO_Target_GetStatus();  ///  needed to clear pending interrupt ????
//}

/******************************************************************************
* Function Name: isrTimeout
*******************************************************************************
*
*  Interrupt Service Routine for Timer interrupt
*
******************************************************************************/
CY_ISR(isr_Timeout)
{
   uint8 TimeoutTest = 0;
	
   Timeout_Timer_ClearInterrupt(Timeout_Timer_INTR_MASK_CC_MATCH);
	/* Check for SGPIO bus activity since the last 1ms interrupt */
	TimeoutTest = SGPIO_Target_GetTimeoutStatus();
   if (0 != TimeoutTest)
	{
		/* No bus activity detected */
		if (++TIMEOUT64_COUNTER > 63)
		{
			TIMEOUT64_COUNTER = 63;
			TIMEOUT64_FLAG = 1;		
			SGPIO_Target_Stop(); 
			SGPIOActivityReg_Write(OFF);
		   StatusControlReg_Write(OFF);
		}
	}	
	else
	{
		TIMEOUT64_COUNTER = 0;		/* Bus activity detected */
   }
	/* Reset the SGPIO bus activity detection logic */
	SGPIO_Target_ResetTimeout();
}

/* [] END OF FILE */
